@@ -93,8 +93,8 @@ require POSIX;
 @ISA = qw(Exporter Date::Say::Czech);
 @EXPORT_OK = qw(date_to_say time_to_say);
 %EXPORT_TAGS = ( ALL => [qw(year_to_say date_to_say time_to_say month_to_say day_to_say)] );
-$VERSION = "0.03";
-$AUTHOR = 'Jiri Vaclavik <jiri.vaclavik@gmail.com>';
+$VERSION = "0.04";
+$AUTHOR = 'Jiri Vaclavik <jiri.vaclavik@NOSPAMgmailNOSPAM.com>';
 
 my %cipher = (1 => "jedna", 2 => "dva", 3 => "ti", 4 => "tyi", 5 => "pt", 6 => "est", 7 => "sedm", 8 => "osm", 9 => "devt", 10 => "deset", 11 => "jedenct", 12 => "dvanct", 13 => "tinct", 14 => "trnct", 15 => "patnct", 16 => "estnct", 17 => "sedmnct", 18 => "osmnct", 19 => "devatenct");
 my %specialcipher = (1 => "prvnho", 2 => "druhho", 3 => "tetho", 4 => "tvrtho", 5 => "ptho", 6 => "estho", 7 => "sedmho", 8 => "osmho", 9 => "devtho", 10 => "destho", 11 => "jedenctho", 12 => "dvanctho", 13 => "tinctho", 14 => "trnctho", 15 => "patnctho", 16 => "estnctho", 17 => "sedmnctho", 18 => "osmnctho", 19 => "devatenctho");
